==> mule-tests-integration-4.8.10-20251105.214723-4-test-sources.jar: org/mule/test/integration/properties/CustomPropertiesResolverExtensionDeprecatedComplexTestCase.java <==
/*
 * Copyright 2023 Salesforce, Inc. All rights reserved.
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */
package org.mule.test.integration.properties;

import static org.mule.test.allure.AllureConstants.ConfigurationProperties.CONFIGURATION_PROPERTIES;
import static org.mule.test.allure.AllureConstants.ConfigurationProperties.ComponentConfigurationAttributesStory.CONFIGURATION_PROPERTIES_RESOLVER_STORY;

import static org.hamcrest.core.Is.is;
import static org.junit.Assert.assertThat;

import org.mule.runtime.api.component.ConfigurationProperties;
import org.mule.test.AbstractIntegrationTestCase;

import javax.inject.Inject;

import org.junit.Test;

import io.qameta.allure.Feature;
import io.qameta.allure.Issue;
import io.qameta.allure.Story;

@Feature(CONFIGURATION_PROPERTIES)
@Story(CONFIGURATION_PROPERTIES_RESOLVER_STORY)
public class CustomPropertiesResolverExtensionDeprecatedComplexTestCase extends AbstractIntegrationTestCase {

  @Inject
  private ConfigurationProperties configurationProperties;

  @Override
  protected String getConfigFile() {
    return "properties/custom-properties-resolver-extension-deprecated-complex-config.xml";
  }

  @Test
  @Issue("MULE-19936")
  public void propertiesAreResolvedCorrectly() {
    assertThat(configurationProperties.resolveStringProperty("textsFromComplexParams").get(),
               is("complex,listedText1,listedText2,listed1,listed2,mappedA,mappedB"));
  }

}

==> mule-tests-integration-4.11.0-20251111.164015-114-test-sources.jar: org/mule/test/integration/properties/CustomPropertiesResolverExtensionDeprecatedComplexTestCase.java <==
/*
 * Copyright 2023 Salesforce, Inc. All rights reserved.
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */
package org.mule.test.integration.properties;

import static org.mule.test.allure.AllureConstants.ConfigurationProperties.CONFIGURATION_PROPERTIES;
import static org.mule.test.allure.AllureConstants.ConfigurationProperties.ComponentConfigurationAttributesStory.CONFIGURATION_PROPERTIES_RESOLVER_STORY;

import static org.hamcrest.MatcherAssert.assertThat;
import static org.hamcrest.core.Is.is;

import org.mule.runtime.api.component.ConfigurationProperties;
import org.mule.test.AbstractIntegrationTestCase;

import org.junit.Test;

import io.qameta.allure.Feature;
import io.qameta.allure.Issue;
import io.qameta.allure.Story;

import jakarta.inject.Inject;

@Feature(CONFIGURATION_PROPERTIES)
@Story(CONFIGURATION_PROPERTIES_RESOLVER_STORY)
public class CustomPropertiesResolverExtensionDeprecatedComplexTestCase extends AbstractIntegrationTestCase {

  @Inject
  private ConfigurationProperties configurationProperties;

  @Override
  protected String getConfigFile() {
    return "properties/custom-properties-resolver-extension-deprecated-complex-config.xml";
  }

  @Test
  @Issue("MULE-19936")
  public void propertiesAreResolvedCorrectly() {
    assertThat(configurationProperties.resolveStringProperty("textsFromComplexParams").get(),
               is("complex,listedText1,listedText2,listed1,listed2,mappedA,mappedB"));
  }

}
